OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migrace probíhá. Počkejte než bude dokončena",
    "Migration started …" : "Migrace spuštěna…",
    "Saved" : "Uloženo",
    "Not saved" : "Neuloženo",
    "Sending…" : "Odesílání…",
    "Email sent" : "Email odeslán",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Došlo k chybě. Nahrajte ASCII-kódovaný PEM certifikát.",
    "Valid until {date}" : "Platný do {date}",
    "Delete" : "Smazat",
    "Local" : "Místní",
    "Private" : "Soukromý",
    "Only visible to local users" : "Viditelný pouze pro místní uživatele",
    "Only visible to you" : "Viditelný pouze pro vás",
    "Contacts" : "Kontakty",
    "Visible to local users and to trusted servers" : "Viditelné pro místní uživatele a důvěryhodné servery",
    "Public" : "Veřejný",
    "Will be synced to a global and public address book" : "Bude synchronizováno do globálního a veřejného adresáře",
    "Verify" : "Ověřit",
    "Verifying …" : "Ověřování…",
    "Unable to change password" : "Změna hesla se nezdařila",
    "Very weak password" : "Velmi slabé heslo",
    "Weak password" : "Slabé heslo",
    "So-so password" : "Středně silné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Odolné heslo",
    "An error occurred while changing your language. Please reload the page and try again." : "Při změně jazyka došlo k chybě. Znovu načtěte stránku a zkuste to ještě jednou.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Došlo k chybě při změně místních a jazykových nastavení. Načtěte stránku znovu a zopakujte pokus.",
    "Select a profile picture" : "Vyberte profilový obrázek",
    "Week starts on {fdow}" : "Týden začíná v {fdow}",
    "Groups" : "Skupiny",
    "Group list is empty" : "Seznam skupin je prázdný.",
    "Unable to retrieve the group list" : "Nedaří se získat seznam skupiny",
    "{actor} added you to group {group}" : "{actor} vás přidal(a) do skupiny {group}",
    "You added {user} to group {group}" : "Přidali jste {user} do skupiny {group}",
    "{actor} added {user} to group {group}" : "{actor} přidal(a) {user} do skupiny {group}",
    "An administrator added you to group {group}" : "Správce vás přidal do skupiny {group}",
    "An administrator added {user} to group {group}" : "Správce přidal {user} do skupiny {group}",
    "{actor} removed you from group {group}" : "{actor} vás odebral(a) ze skupiny {group}",
    "You removed {user} from group {group}" : "Odebrali jste {user} ze skupiny {group}",
    "{actor} removed {user} from group {group}" : "{actor} odebral(a) {user} ze skupiny {group}",
    "An administrator removed you from group {group}" : "Správce vás odebral ze skupiny {group}",
    "An administrator removed {user} from group {group}" : "Správce odebral {user} ze skupiny {group}",
    "Your <strong>group memberships</strong> were modified" : "Vaše <strong>členství ve skupinách</strong> bylo upraveno",
    "{actor} changed your password" : "{actor} změnil(a) vaše heslo",
    "You changed your password" : "Změnili jste své heslo",
    "Your password was reset by an administrator" : "Vaše heslo bylo resetováno správcem",
    "{actor} changed your email address" : "{actor} změnil(a) vaši emailovou adresu",
    "You changed your email address" : "Změnili jste svou emailovou adresu",
    "Your email address was changed by an administrator" : "Vaše emailová adresa byla změněna správcem",
    "You created app password \"{token}\"" : "Vytvořili jste heslo pro aplikaci „{token}“",
    "You deleted app password \"{token}\"" : "Smazali jste heslo pro aplikaci „{token}“",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Přejmenovali jste heslo aplikace „{token}“ na „{newToken}“",
    "You granted filesystem access to app password \"{token}\"" : "Udělili jste přístup k souborovému systému aplikaci, používající heslo „{token}“",
    "You revoked filesystem access from app password \"{token}\"" : "Zrušili jste přístup k souborovému systému pro aplikaci, využívající heslo „{token}“",
    "Security" : "Zabezpečení",
    "You successfully logged in using two-factor authentication (%1$s)" : "Úspěšně jste se přihlásili pomocí dvoufázového ověření (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pokus o přihlášení s použitím dvoufázové autentizace se nezdařil (%1$s)",
    "Remote wipe was started on %1$s" : "Vzdálené vymazání přístroje spuštěno pro %1$s",
    "Remote wipe has finished on %1$s" : "Vzdálené vymazání přístroje dokončeno pro %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Vaše <strong>heslo</strong> nebo <strong>email</strong> bylo změněno",
    "Couldn't remove app." : "Nepodařilo se odebrat aplikaci.",
    "Couldn't update app." : "Nelze aktualizovat aplikaci.",
    "Wrong password" : "Nesprávné heslo",
    "No user supplied" : "Nebyl uveden uživatel",
    "Authentication error" : "Chyba přihlášení",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Zadejte správcovské heslo pro obnovu, jinak budou všechna uživatelská data ztracena.",
    "Wrong admin recovery password. Please check the password and try again." : "Chybné správcovské heslo pro obnovu. Překontrolujte správnost hesla a zkuste to znovu.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Podpůrná vrstva nepodporuje změnu hesla, ale uživatelův šifrovací klíč byl aktualizován.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Instalovat a aktualizovat aplikace pomocí obchodu nebo Sdíleného Cloudového Úložiště",
    "Federated Cloud Sharing" : "Propojené cloudové sdílení",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL používá zastaralou verzi %1$s (%2$s). Aktualizujte operační systém jinak funkce jako například %3$s nebudou fungovat spolehlivě.",
    "Invalid SMTP password." : "Neplatné heslo SMTP.",
    "Email setting test" : "Zkouška nastavení e-mailu",
    "Well done, %s!" : "Úspěšně nastaveno, %s!",
    "If you received this email, the email configuration seems to be correct." : "Pokud přišel tento email, konfigurace pro odesílání emailů se zdá být v pořádku.",
    "Email could not be sent. Check your mail server log" : "Email se nepodařilo odeslat. Podívejte se do záznamu událostí (log) svého emailového serveru.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Při odesílání e-mailu nastala chyba. Překontrolujte prosím svá nastavení. (Error: %s)",
    "You need to set your user email before being able to send test emails." : "Pro možnost odeslání zkušebních emailů musíte nejprve nastavit svou emailovou adresu.",
    "Invalid mail address" : "Neplatná emailová adresa",
    "Settings saved" : "Nastavení uloženo",
    "Unable to change full name" : "Nelze změnit celé jméno",
    "Unable to change email address" : "Nepodařilo se změnit emailovou adresu",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pokud chcete ověřit váš Twitter účet, napište následující tweet (ujistěte se, že ho zasíláte bez zalomení řádků):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pro ověřování vašich webových stránek uložte následující obsah v kořenovém adresáři webové prezentace v umístění '.well-known/CloudIdVerificationCode.txt' (ujistěte se, že byl text vložen jako jediný řádek)",
    "%1$s changed your password on %2$s." : "%1$s změnil(a) vaše heslo na %2$s.",
    "Your password on %s was changed." : "Vaše heslo na %s bylo změněno.",
    "Your password on %s was reset by an administrator." : "Vaše heslo na %s bylo resetováno správcem.",
    "Password for %1$s changed on %2$s" : "Heslo pro %1$s na %2$s změněno ",
    "Password changed for %s" : "Změna hesla pro %s",
    "If you did not request this, please contact an administrator." : "Pokud jste o toto nežádali, obraťte se na správce.",
    "Your email address on %s was changed." : "Vaše emailová adresa na %s byla změněna.",
    "Your email address on %s was changed by an administrator." : "Vaše emailová adresa na %s byla změněna správcem.",
    "Email address for %1$s changed on %2$s" : "Emailová adresa pro %1$s se na %2$s změnila",
    "Email address changed for %s" : "Emailová adresa pro %s byla změněna",
    "The new email address is %s" : "Nová emailová adresa je %s",
    "Your %s account was created" : "Účet %s byl vytvořen",
    "Welcome aboard" : "Vítejte na palubě",
    "Welcome aboard %s" : "Vítej na palubě, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Vítejte ve svém %s účtu, můžete vkládat, chránit a sdílet svoje data.",
    "Your username is: %s" : "Vaše uživatelské jméno je: %s",
    "Set your password" : "Nastavte vaše heslo",
    "Go to %s" : "Jít na %s",
    "Install Client" : "Nainstalovat klienta",
    "Logged in user must be a subadmin" : "Je třeba, aby přihlášený uživatel byl dílčím správcem",
    "Create" : "Vytvořit",
    "Change" : "Změnit",
    "Share" : "Sdílet",
    "Unlimited" : "Neomezeně",
    "Verifying" : "Ověřuje se",
    "Nextcloud settings" : "Nextcloud nastavení",
    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvoufázové ověřování je možné vynutit pro všechny\tuživatele a konkrétní skupiny. Pokud nemají nastaveného poskytovatele dvoufázového ověřování, nebudou se moci přihlásit do systému.",
    "Enforce two-factor authentication" : "Vynutit dvoufázové ověřování",
    "Limit to groups" : "Omezit na skupiny",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Vynucení dvoufázového ověřování je možné nastavit pouze pro určité skupiny.",
    "Two-factor authentication is enforced for all\tmembers of the following groups." : "Dvoufázové ověřování je vynucováno pro všechny\tčleny následujících skupin.",
    "Enforced groups" : "Vynucené skupiny",
    "Two-factor authentication is not enforced for\tmembers of the following groups." : "Dvoufázové ověřování není vynucováno pro\tčleny následujících skupin.",
    "Excluded groups" : "Vynechané skupiny",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Když jsou skupiny vybrány/vynechány, je pro zjišťování zda je uživateli vynuceno dvoufázové (2FA) ověřování použita následující logika: Pokud nejsou vybrány žádné skupiny, je 2FA zapnuto pro všechny kromě členů vynechaných skupin. Pokud jsou nějaké skupiny vybrány, je 2FA zapnuto pro všechny jejich členy. Pokud je uživatel členem jak vybrané, tak vynechané skupiny, pak má ta vybraná přednost a 2FA je vynuceno.",
    "Save changes" : "Uložit změny",
    "This app is supported via your current Nextcloud subscription." : "Tato aplikace je podporována prostřednictvím vašeho stávajícího předplatného Nextcloud.",
    "Supported" : "Podporováno",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Oficiální aplikace jsou vyvíjeny komunitou. Poskytují klíčové funkce a jsou připravené na produkční nasazení.",
    "Official" : "Oficiální",
    "by" : "od",
    "Update to {version}" : "Aktualizovat na {version}",
    "Remove" : "Odstranit",
    "Disable" : "Zakázat",
    "All" : "Vše",
    "Limit app usage to groups" : "Omezit používání skupin na skupiny",
    "No results" : "Žádné výsledky",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tato aplikace nemá nastavenou žádnou minimální verzi Nextcloudu. To se v budoucnu projeví jako chyba.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tato aplikace nemá nastavenou žádnou maximální verzi Nextcloudu. To se v budoucnu projeví jako chyba.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tuto aplikaci nelze nainstalovat, protože nejsou splněny následující závislosti:",
    "View in store" : "Zobrazit v obchodě",
    "Visit website" : "Navštívit webovou stránku",
    "Report a bug" : "Nahlásit chybu",
    "User documentation" : "Dokumentace pro uživatele",
    "Admin documentation" : "Dokumentace pro administrátory",
    "Developer documentation" : "Vývojářská dokumentace",
    "Update to {update}" : "Aktualizovat na {update}",
    "Results from other categories" : "Výsledky z ostatních kategorií",
    "No apps found for your version" : "Nebyly nalezeny aplikace pro vaši verzi",
    "Disable all" : "Zakázat vše",
    "Enable all" : "Zapnout vše",
    "Download and enable" : "Stáhnout a zapnout",
    "Enable" : "Povolit",
    "Enable untested app" : "Zapnout nevyzkoušenou aplikaci",
    "The app will be downloaded from the app store" : "Aplikace bude stažena z obchodu aplikací",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tato aplikace není označena jako kompatibilní s vámi používanou verzí Nexcloud. Pokud budete pokračovat, pořád budete moci aplikaci nainstalovat. Uvědomte si ale, že aplikace nemusí fungovat, jak je očekáváno.",
    "Marked for remote wipe" : "Označeno k vymazání na dálku",
    "Device settings" : "Nastavení zařízení",
    "Allow filesystem access" : "Umožnit přístup k souborovému systému",
    "Rename" : "Přejmenovat",
    "Revoke" : "Odvolat",
    "Wipe device" : "Vymazat zařízení",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Odstranění tohoto tokenu může zabránit vymazání přístroje, pokud nebyl proces vymazání do teď zahájen.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome pro Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Aplikace Nextcloud pro iOS",
    "Nextcloud Android app" : "Aplikace Nextcloud pro Android",
    "Nextcloud Talk for iOS" : "Nextcloud Talk pro iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk pro Android",
    "Sync client - {os}" : "Synchronizační klient – {os}",
    "This session" : "Toto sezení",
    "Device" : "Přístroj",
    "Last activity" : "Poslední aktivita",
    "Devices & sessions" : "Zařízení a sezení",
    "Web, desktop and mobile clients currently logged in to your account." : "Weboví, desktopoví a mobilní klienti aktuálně přihlášení k vašemu účtu.",
    "Do you really want to wipe your data from this device?" : "Opravdu chcete vymazat svá data z tohoto zařízení?",
    "Confirm wipe" : "Potvrdit vymazání",
    "Error while creating device token" : "Chyba při vytváření tokenů přístroje",
    "Error while updating device token scope" : "Chyba při aktualizaci rozsahu tokenu zařízení",
    "Error while updating device token name" : "Chyba při aktualizaci názvu tokenu zařízení",
    "Error while deleting the token" : "Chyba při mazání tokenu",
    "Error while wiping the device with the token" : "Chyba při vymazávání zařízení s tokenem",
    "App name" : "Název aplikace",
    "Create new app password" : "Vytvořit nové heslo aplikace",
    "Use the credentials below to configure your app or device." : "Pro nastavení aplikace nebo zařízení použijte níže uvedené údaje.",
    "For security reasons this password will only be shown once." : "Toto heslo bude z bezpečnostních důvodů zobrazeno pouze jedenkrát.",
    "Username" : "Uživatelské jméno",
    "Password" : "Heslo",
    "Done" : "Dokončeno",
    "Show QR code for mobile apps" : "Zobrazit QR kód pro mobilní aplikace",
    "Copied!" : "Zkopírováno!",
    "Copy" : "Zkopírovat",
    "Could not copy app password. Please copy it manually." : "Nedaří se zkopírovat heslo pro aplikaci. Zkopírujte ho ručně.",
    "You do not have permissions to see the details of this user" : "Nemáte oprávnění k zobrazení podrobností o tomto uživateli",
    "The backend does not support changing the display name" : "Podpůrná vrstva nepodporuje změnu zobrazovaného názvu",
    "New password" : "Nové heslo",
    "Add user in group" : "Přidat uživatele do skupiny",
    "Set user as admin for" : "Nastavit uživatele jako správce pro",
    "Select user quota" : "Vybrat kvótu uživatele",
    "No language set" : "Není nastaven jazyk",
    "Never" : "Nikdy",
    "Delete user" : "Smazat uživatele",
    "Wipe all devices" : "Vymazat všechna zařízení",
    "Disable user" : "Znepřístupnit uživatelský účet",
    "Enable user" : "Zpřístupnit uživatelský účet",
    "Resend welcome email" : "Znovu poslat uvítací email",
    "{size} used" : "{size} použito",
    "Welcome mail sent!" : "Uvítací email odeslán!",
    "Display name" : "Zobrazované jméno",
    "Email" : "Email",
    "Group admin for" : "Správce skupiny",
    "Quota" : "Kvóta",
    "Language" : "Jazyk",
    "Storage location" : "Úložiště dat",
    "User backend" : "Backend uživatelů",
    "Last login" : "Poslední přihlášení",
    "Will be autogenerated" : "Bude automaticky vytvořeno",
    "Default language" : "Výchozí jazyk",
    "Add a new user" : "Přidat nového uživatele",
    "No users in here" : "Nejsou zde žádní uživatelé",
    "Default quota" : "Výchozí kvóta",
    "Common languages" : "Běžné jazyky",
    "All languages" : "Všechny jazyky",
    "Password change is disabled because the master key is disabled" : "Změna hesla je vypnutá protože je vypnutý hlavní klíč",
    "Your apps" : "Vaše aplikace",
    "Active apps" : "Aktivní aplikace",
    "Disabled apps" : "Vypnuté aplikace",
    "Updates" : "Aktualizace",
    "App bundles" : "Sady aplikací",
    "{license}-licensed" : "licencováno pod {license}",
    "New user" : "Nový uživatel",
    "Default quota:" : "Výchozí kvóta:",
    "Select default quota" : "Vybrat výchozí kvótu",
    "Show Languages" : "Zobrazit jazyky",
    "Show last login" : "Zobrazit poslední přihlášení",
    "Show user backend" : "Zobrazit vedení uživatelů",
    "Show storage path" : "Zobrazit cestu k úložišti",
    "Remove group" : "Odebrat skupinu",
    "Admins" : "Správci",
    "Disabled users" : "Zakázaní uživatelé",
    "Everyone" : "Všichni",
    "Add group" : "Přidat skupinu",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Chystáte se smazat skupinu {group}. Uživatelé NEbudou smazáni.",
    "Please confirm the group removal " : "Potvrďte odstranění skupiny",
    "An error occured during the request. Unable to proceed." : "Během požadavku došlo k chybě. Nelze pokračovat.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikace byla povolena ale je třeba ji aktualizovat. Za 5 sekund budete přesměrování na stránku pro aktualizaci.",
    "App update" : "Aktualizace aplikace",
    "Error: This app can not be enabled because it makes the server unstable" : "Chyba: tuto aplikaci nelze zapnout, protože způsobuje nestabilitu serveru",
    "SSL Root Certificates" : "Kořenové certifikáty SSL",
    "Common Name" : "Common Name",
    "Valid until" : "Platný do",
    "Issued By" : "Vydal",
    "Valid until %s" : "Platný do %s",
    "Import root certificate" : "Import kořenového certifikátu",
    "Administrator documentation" : "Dokumentace pro správu",
    "Documentation" : "Dokumentace",
    "Forum" : "Diskuzní fórum",
    "None" : "Žádné",
    "Login" : "Přihlásit",
    "Plain" : "Čistý text",
    "NT LAN Manager" : "Správce NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Emailový server",
    "Open documentation" : "Otevřít dokumentaci",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Je důležité tento server nastavit, aby mohly být odesílány emaily, jako jsou např. resety hesla a upozornění.",
    "Send mode" : "Mód odesílání",
    "Encryption" : "Šifrování",
    "Sendmail mode" : "Režim sendmail",
    "From address" : "Adresa odesílatele",
    "mail" : "email",
    "Authentication method" : "Metoda ověření",
    "Authentication required" : "Vyžadováno ověření",
    "Server address" : "Adresa serveru",
    "Port" : "Port",
    "Credentials" : "Přihlašovací údaje",
    "SMTP Username" : "SMTP uživatelské jméno ",
    "SMTP Password" : "SMTP heslo",
    "Save" : "Uložit",
    "Test email settings" : "Test nastavení e-mailu",
    "Send email" : "Odeslat email",
    "Security & setup warnings" : "Upozornění zabezpečení a nastavení",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pro zabezpečení a optimální výkon instance Nextcloud je důležitě, aby vše bylo správně nastaveno. Jako pomoc, instance samotná automaticky ověřuje některá nastavení. Více informací je k nalezení v dokumentaci, sekci Tipy a Triky.",
    "All checks passed." : "Všechny testy proběhly úspěšně.",
    "There are some errors regarding your setup." : "Jsou zde nějaké chyby ohledně vašeho nastavení.",
    "There are some warnings regarding your setup." : "Jsou zde nějaká varování ohledně vašeho nastavení.",
    "Checking for system and security issues." : "Kontrola systému a problémů se zabezpečením.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Důkladně si přečtěte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">průvodce instalací ↗</a> a zkontrolujte, že v <a href=\"%2$s\">záznamu událostí</a> nejsou žádné chyby ani varování.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Zkontrolujte zabezpečení svého Nextcloud přes <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">náš skener zabezpečení ↗</a>.",
    "Version" : "Verze",
    "Two-Factor Authentication" : "Dvoufázové ověření",
    "Server-side encryption" : "Šifrování na straně serveru",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifrování na straně serveru umožňuje zašifrovat soubory, které jsou na tento server nahrávány. To přináší omezení jako třeba výkonnostní omezení, takže to povolte jen pokud je třeba.",
    "Enable server-side encryption" : "Povolit šifrování na straně serveru",
    "Please read carefully before activating server-side encryption: " : "Pročtěte důkladně před zapnutím šifrování dat na serveru:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Poté co je zapnuto šifrování, jsou od toho bodu všechny nahrávané soubory šifrovány serverem. Vypnout šifrování bude možné pouze později, až bude šifrovací modul tuto možnost podporovat a po splnění všech nutných podmínek (tzn. nastavení klíčů pro obnovení).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrování samotné ještě negarantuje bezpečnost systému. Přečtěte si prosím dokumentaci, chcete-li se dozvědět více informací o tom, jak aplikace pro šifrování funguje a jaké jsou podporované případy použití.",
    "Be aware that encryption always increases the file size." : "Mějte na paměti, že šifrování vždy navýší velikost souboru.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Je vždy dobré vytvářet pravidelné zálohy svých dat, v případě zapnutého šifrování také zajistěte zálohu šifrovacích klíčů společně se zálohou dat.",
    "This is the final warning: Do you really want to enable encryption?" : "Toto je poslední varování: Opravdu si přejete zapnout šifrování?",
    "Enable encryption" : "Povolit šifrování",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Není načten žádný šifrovací modul, povolte ho v nabídce aplikace.",
    "Select default encryption module:" : "Vybrat výchozí šifrovací modul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Je třeba přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou. Povolte prosím „Default encryption module“ a spusťte příkaz 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Je třeba přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou.",
    "Start migration" : "Spustit migraci",
    "Background jobs" : "Úkoly na pozadí",
    "Last job ran %s." : "Poslední úloha byla vykonána: %s.",
    "Last job execution ran %s. Something seems wrong." : "Minulá úloha byla vykonána: %s. Zdá se, že něco není v pořádku.",
    "Background job didn’t run yet!" : "Úloha na pozadí ještě nebyla spuštěná!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Pro optimální výkon je důležité správně nastavit úlohy spouštěné na pozadí. Pro větší instance je doporučenou metodou použití systémového plánovače (cron). Více informací naleznete v dokumentaci.",
    "Pick background job setting" : "Vybrat nastavení úlohy na pozadí",
    "Execute one task with each page loaded" : "Spustit jednu úlohu s načtením každé stránky",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php je zaregistrován na službě webcron a bude přes HTTP volán každých 5 minut.",
    "Use system cron service to call the cron.php file every 5 minutes." : "Použít systémový plánovač (cron) pro volání souboru cron.php každých 5 minut.",
    "The cron.php needs to be executed by the system user \"%s\"." : "Je třeba, aby cron.php bylo spouštěno s právy systémového uživatele „%s“.",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Pro spuštění je potřeba PHP POSIX rozšíření. Více informací lze nalézt v {linkstart}dokumentaci k PHP{linkend}.",
    "Sharing" : "Sdílení",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Jako správce můžete upravit chování sdílení. Více informací naleznete v dokumentaci.",
    "Allow apps to use the Share API" : "Umožnit aplikacím používat API sdílení",
    "Allow users to share via link" : "Umožnit uživatelům sdílet pomocí odkazů",
    "Allow public uploads" : "Umožnit veřejné nahrávání souborů",
    "Always ask for a password" : "Vždy se zeptat na heslo",
    "Enforce password protection" : "Vynutit ochranu heslem",
    "Set default expiration date" : "Nastavit výchozí datum skončení platnosti",
    "Expire after " : "Platnost skončí po",
    "days" : "dnech",
    "Enforce expiration date" : "Vynutit datum skončení platnosti",
    "Allow resharing" : "Povolit znovu-sdílení",
    "Allow sharing with groups" : "Povolit sdílení se skupinami",
    "Restrict users to only share with users in their groups" : "Povolit sdílení pouze mezi uživateli v rámci skupiny",
    "Exclude groups from sharing" : "Vyjmout skupiny ze sdílení",
    "These groups will still be able to receive shares, but not to initiate them." : "Těmto skupinám bude stále možno sdílet, nemohou ale sami sdílet ostatním.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Povolit automatické dokončení uživatelského jména v dialogovém okně sdílení. Pokud je tato volba zakázána, je třeba zadat úplné uživatelské jméno nebo emailovou adresu.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Zobrazit text upozornění na stránce pro nahrání veřejného odkazu. (Zobrazit pouze pokud je seznam souborů skrytý.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Tento text bude zobrazen on stránce pro nahrání veřejného odkazu, pokud bude seznam souborů skrytý.",
    "Default share permissions" : "Výchozí oprávnění sdílení",
    "Personal" : "Osobní",
    "Administration" : "Správa",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Vyvíjeno {communityopen}komunitou Nextcloud{linkclose}, {githubopen}zdrojové kódy{linkclose} jsou licencovány pod {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Lajkujte naše stránky na Facebooku",
    "Follow us on Twitter" : "Sledujte nás na Twitteru",
    "Follow us on Mastodon" : "Sledujte nás na Mastodon",
    "Check out our blog" : "Podívejte se na náš blog",
    "Subscribe to our newsletter" : "Odebírejte náš zpravodaj",
    "Profile picture" : "Profilový obrázek",
    "Upload new" : "Nahrát nový",
    "Select from Files" : "Vybrat ze Souborů",
    "Remove image" : "Odebrat obrázek",
    "png or jpg, max. 20 MB" : "png nebo jpg, max. 20 MB",
    "Picture provided by original account" : "Obrázek je poskytován původním účtem",
    "Cancel" : "Zrušit",
    "Choose as profile picture" : "Vybrat jako profilový obrázek",
    "Details" : "Podrobnosti",
    "You are a member of the following groups:" : "Jste členem následujících skupin:",
    "You are using <strong>%s</strong>" : "Používáte <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Používáte <strong>%1$s</strong> z <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "Celé jméno",
    "No display name set" : "Jméno pro zobrazení nenastaveno",
    "Your email address" : "Vaše emailová adresa",
    "No email address set" : "Emailová adresa není nastavena",
    "For password reset and notifications" : "Pro obnovení hesla a upozornění",
    "Phone number" : "Telefonní číslo",
    "Your phone number" : "Vlastní telefonní číslo",
    "Address" : "Adresa",
    "Your postal address" : "Vlastní poštovní adresa",
    "Website" : "Webová stránka",
    "It can take up to 24 hours before the account is displayed as verified." : "Může trvat až 24 hodin, než se účet zobrazí jako ověřený.",
    "Link https://…" : "Odkaz https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Přezdívka na Twitteru @…",
    "Help translate" : "Pomoci s překladem",
    "Locale" : "Místní a jazyková nastavení",
    "Current password" : "stávající heslo",
    "Change password" : "Změnit heslo",
    "Use a second factor besides your password to increase security for your account." : "Pro zlepšení zabezpečení vašeho účtu použijte vedle hesla také druhý faktor.",
    "Disconnect" : "Odpojit",
    "Not supported!" : "Nepodporováno!",
    "Press ⌘-C to copy." : "Zkopírujete stisknutím ⌘-C.",
    "Press Ctrl-C to copy." : "Zkopírujete stisknutím Ctrl-C.",
    "Error while loading browser sessions and device tokens" : "Chyba při načítání sezení prohlížeče a tokenů přístroje",
    "Afrikaans (South Africa)" : "afrikánština (Jihoafrická republika)",
    "Afrikaans" : "Afrikánština",
    "Albanian (Albania)" : "albánština (Albánie)",
    "Albanian" : "Albánština",
    "Amharic (Ethiopia)" : "amharština (Etiopie)",
    "Arabic (Algeria)" : "arabština (Alžír)",
    "Arabic (Egypt)" : "Arabština (Egypt)",
    "Arabic (Iraq)" : "Arabština (Irák)",
    "Arabic (Jordan)" : "Arabština (Jordán)",
    "Arabic (Kuwait)" : "Arabština (Kuvajt)",
    "Arabic (Lebanon)" : "Arabština (Libanon)",
    "Arabic (Libya)" : "Arabština (Libye)",
    "Arabic (Qatar)" : "arabština (Katar)",
    "Arabic (Yemen)" : "arabština (Jemen)",
    "Arabic" : "arabština",
    "Armenian" : "arménština",
    "Assamese" : "Ásámština",
    "Asu (Tanzania)" : "asu (Tanzanie)",
    "Basque" : "baskičtina",
    "Belarusian" : "Běloruština",
    "Bosnian" : "bosenština",
    "Bulgarian (Bulgaria)" : "bulharština (Bulharsko)",
    "Bulgarian" : "bulharština",
    "Catalan (Spain)" : "katalánština (Španělsko)",
    "Catalan" : "Katalánština",
    "Chinese (Traditional Han)" : "Čínština (tradiční)",
    "Chinese" : "Čínština",
    "Croatian (Croatia)" : "Chorvatština (Chorvatsko)",
    "Croatian" : "chorvatština",
    "Czech (Czech Republic)" : "Čeština (Česko)",
    "Czech" : "Čeština",
    "Danish (Denmark)" : "dánština (Dánsko)",
    "Danish" : "Dánština",
    "Dutch (Netherlands)" : "nizozemština (Nizozemsko)",
    "Embu" : "Embu",
    "English (Australia)" : "angličtina (Austrálie)",
    "English (Belgium)" : "angličtina (Belgie)",
    "English (Canada)" : "angličtina (Kanada)",
    "English (Guam)" : "angličtina (Guam)",
    "English (India)" : "angličtina (Indie)",
    "English (Ireland)" : "angličtina (Irsko)",
    "English (Jamaica)" : "angličtina (Jamajka)",
    "English (Malta)" : "angličtina (Malta)",
    "English (Mauritius)" : "Angličtina (Maurícius)",
    "English (Namibia)" : "angličtina (Namibie)",
    "English (New Zealand)" : "angličtina (Nový Zéland)",
    "English (Philippines)" : "angličtina (Filipíny)",
    "English (South Africa)" : "Angličtina (Jihoafrická republika)",
    "English (United Kingdom)" : "Angličtina (Spojené království)",
    "English (United States)" : "angličtina (Spojené Státy)",
    "English" : "Angličtina",
    "Esperanto" : "Esperanto",
    "Estonian (Estonia)" : "estonština (Estonsko)",
    "Estonian" : "Estonština",
    "Faroese" : "faerština",
    "Finnish (Finland)" : "Finština (Finsko)",
    "Finnish" : "Finština",
    "French (Belgium)" : "francouzština (Belgie)",
    "French (Burkina Faso)" : "Francouzština (Burkina Faso)",
    "French (Canada)" : "Francouzština (Kanada)",
    "French (Congo - Kinshasa)" : "francouzština (Kongo-Kinshasa)",
    "French (France)" : "francouzština (Francie)",
    "French (Mali)" : "francouzština (Mali)",
    "French (Rwanda)" : "francouzština (Rwanda)",
    "French (Senegal)" : "francouzština (Senegal)",
    "French (Switzerland)" : "francouzština (Švýcarsko)",
    "French (Togo)" : "francouzština (Togo)",
    "French" : "Francouzština",
    "Galician" : "galicijština",
    "Georgian" : "gruzínština",
    "German (Austria)" : "němčina (Rakousko)",
    "German (Belgium)" : "němčina (Belgie)",
    "German (Germany)" : "němčina (Německo)",
    "German (Luxembourg)" : "němčina (Lucembursko)",
    "German (Switzerland)" : "němčina (Švýcarsko)",
    "German" : "Němčina",
    "Greek (Cyprus)" : "řečtina (Kypr)",
    "Greek (Greece)" : "řečtina (Řecko)",
    "Greek" : "Řečtina",
    "Hausa" : "hauština",
    "Hawaiian" : "havajština",
    "Hebrew (Israel)" : "hebrejština (Izrael)",
    "Hebrew" : "Hebrejština",
    "Hungarian (Hungary)" : "Maďarština (Maďarsko)",
    "Hungarian" : "Maďarština",
    "Icelandic" : "Islandština",
    "Indonesian (Indonesia)" : "indonéština (Indonésie)",
    "Irish (Ireland)" : "irština (Irsko)",
    "Irish" : "Irština",
    "Italian (Italy)" : "italština (Itálie)",
    "Italian" : "Italština",
    "Japanese (Japan)" : "japonština (Japonsko)",
    "Japanese" : "Japonština",
    "Kabuverdianu (Cape Verde)" : "kapverdština (Kapverdy)",
    "Kabyle (Algeria)" : "kabylština (Alžírsko)",
    "Kalaallisut" : "grónština",
    "Kannada" : "kannadština",
    "Kinyarwanda" : "rwandština",
    "Korean (South Korea)" : "Korejština (Severní Korea)",
    "Korean" : "korejština",
    "Latvian (Latvia)" : "lotyština (Lotyšsko)",
    "Latvian" : "Lotyština",
    "Lithuanian (Lithuania)" : "litevština (Litva)",
    "Lithuanian" : "Litevština",
    "Luo (Kenya)" : "luo (Keňa)",
    "Luo" : "luo",
    "Macedonian (Macedonia)" : "makedonština (Makedonie)",
    "Macedonian" : "makedonština",
    "Malagasy (Madagascar)" : "malgaština (Madagaskar)",
    "Malagasy" : "malgaština",
    "Malayalam" : "malajálamština",
    "Manx (United Kingdom)" : "Manština (Velká Británie)",
    "Nepali" : "nepálština",
    "Norwegian Bokmål" : "Norština (Bokmål)",
    "Oromo (Ethiopia)" : "oromština (Etiopie)",
    "Oromo" : "oromština",
    "Persian (Afghanistan)" : "perština (Afghánistán)",
    "Persian (Iran)" : "perština (Írán)",
    "Persian" : "perština",
    "Polish (Poland)" : "polština (Polsko)",
    "Polish" : "Polština",
    "Portuguese (Brazil)" : "portugalština (Brazílie)",
    "Portuguese (Portugal)" : "portugalština (Portugalsko)",
    "Portuguese" : "Portugalština",
    "Romanian (Moldova)" : "rumunština (Moldávie)",
    "Romanian (Romania)" : "rumunština (Rumunsko)",
    "Romanian" : "Rumunština",
    "Russian (Russia)" : "ruština (Rusko)",
    "Russian (Ukraine)" : "ruština (Ukrajina)",
    "Russian" : "Ruština",
    "Samburu" : "samburu",
    "Serbian (Cyrillic, Bosnia and Herzegovina)" : "srbština (azbuka, Bosna a Hercegovina)",
    "Serbian" : "Srbština",
    "Sichuan Yi (China)" : "Ijo (Čína)",
    "Slovak (Slovakia)" : "slovenština (Slovensko)",
    "Slovak" : "Slovenština",
    "Slovenian (Slovenia)" : "slovinština (Slovensko)",
    "Slovenian" : "Slovinština",
    "Somali (Djibouti)" : "somálština (Džibutsko)",
    "Somali (Ethiopia)" : "somálština (Etiopie)",
    "Somali (Kenya)" : "somálština (Keňa)",
    "Somali (Somalia)" : "somálština (Somálsko)",
    "Spanish (Argentina)" : "španělština (Argentina)",
    "Spanish (Bolivia)" : "španělština (Bolívie)",
    "Spanish (Colombia)" : "španělština (Kolumbie)",
    "Spanish (Ecuador)" : "španělština (Ekvádor)",
    "Spanish (Equatorial Guinea)" : "španělština (Rovníková Guinea)",
    "Spanish (Honduras)" : "španělština (Honduras)",
    "Spanish (Latin America)" : "španělština (latinská Amerika)",
    "Spanish (Mexico)" : "španělština (Mexiko)",
    "Spanish (Panama)" : "španělština (Panama)",
    "Spanish (Peru)" : "španělština (Peru)",
    "Spanish (United States)" : "španělština (Spojené Státy)",
    "Spanish" : "Španělština",
    "Swahili (Kenya)" : "svahilština (Keňa)",
    "Swahili (Tanzania)" : "svahilština (Tanzanie)",
    "Swahili" : "Svahilština",
    "Swedish (Finland)" : "švédština (Finsko)",
    "Swedish (Sweden)" : "švédština (Švédsko)",
    "Swedish" : "Švédština",
    "Swiss German (Switzerland)" : "švýcarská němčina (Švýcarsko)",
    "Swiss German" : "Švýcarská němčina",
    "Tachelhit (Latin, Morocco)" : "tašelhit (latinka, Maroko)",
    "Telugu (India)" : "telužština (Indie)",
    "Thai" : "Thajština",
    "Tibetan (India)" : "tibetština (Indie)",
    "Tibetan" : "tibetština",
    "Tonga (Tonga)" : "tongánština (Tonga)",
    "Turkish (Turkey)" : "turečtina (Turecko)",
    "Turkish" : "Turečtina",
    "Ukrainian (Ukraine)" : "ukrajinština (Ukrajina)",
    "Ukrainian" : "Ukrajinština",
    "Uzbek (Cyrillic)" : "uzbečtina (azbuka)",
    "Uzbek (Latin)" : "uzbečtina (latinka)",
    "Uzbek" : "Uzbečtina",
    "Vietnamese (Vietnam)" : "vietnamština (Vietnam)",
    "Vietnamese" : "Vietnamština",
    "Welsh" : "Velština",
    "Yoruba" : "jorubština",
    "Zulu" : "zuluština",
    "Store credentials" : "Ukládat přihlašovací údaje",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php je registrován u služby webcron, aby volal cron.php jednou za 15 minut přes HTTP.",
    "Use system cron service to call the cron.php file every 15 minutes." : "Použít systémovou službu cron pro volání cron.php každých 15 minut.",
    "Follow us on Google+" : "Následujte nás na Google+"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
